//***********************************************************************************//
//*	Project:																		*//
//*																					*//
//*	File:		main.c			 													*//
//*	Version:	1.0																	*//
//*																					*//
//*	Author:		Bob Marlowe															*//
//*	(C) 2018	Jörg Meier Software - Entwicklung briefe@jmeiersoftware.de			*//
//***********************************************************************************//
//***********************************************************************************//
//*																					*//
//*		Principles of Operation														*//
//*																					*//
//*		This project shows the "volatile" error										*//
//*																					*//
//*		All global variables *MUST* be declared volatile when changed				*//
//*		within an interrupt handler.												*//
//*																					*//
//*		Underlying hardware is a CY8CKIT-059										*//
//*																					*//
//***********************************************************************************//

//***********************************************************************************//
//**************** Libraries ********************************************************//
//***********************************************************************************//
#include <project.h>
#include <main.h>

//***********************************************************************************//
//**************** Definitions and Macros *******************************************//
//***********************************************************************************//
//	None yet

//***********************************************************************************//
//******************* Structs, Typedefs and Enums ***********************************//
//***********************************************************************************//
//	None yet

//***********************************************************************************//
//******************* Data Area *****************************************************//
//***********************************************************************************//

//	Optimization level has been set to "speed" 
//	Enable one of the following definitions to see the effect
//	Without the "volatile" the LED will not switch off.

//volatile Bool FlagToCheck = FALSE;
Bool FlagToCheck = FALSE;

//***********************************************************************************//
//****************** Prototypes *****************************************************//
//***********************************************************************************//
CY_ISR_PROTO(TenSecHandler);

//***********************************************************************************//
//**************** Program Area *****************************************************//
//***********************************************************************************//

CY_ISR(TenSecHandler)
{
	TenSecTimer_Stop();									//	Stop the timer
	TenSecTimer_ReadStatusRegister();					//	Clear timer interrupt bit
	
	FlagToCheck = TRUE;									//	Signal that interrupt happened
}
//***********************************************************************************//

void InitializeSystem(void)								//	Start all components, initialize  variables, perform self-test
{
	CyGlobalIntEnable;									//	Enable interrupt handling
	Timeout_StartEx(TenSecHandler);						//	Setup the interrupt handler
	TenSecTimer_Start();								//	Start the timer
	LED_Write(LEDON);									//	Light the LED	
}
//***********************************************************************************//

int main()
{
	InitializeSystem();									//	Setup the project
	
	while(!FlagToCheck) Wait();							//	Wait until the flag is set to true
	LED_Write(LEDOFF);									//	Turn off the LED	

	while(forever)										//	*** Main loop
	{
		Wait();											//	Don't do anything
	}
}
//***********************************************************************************//

